@@ -87,32 +87,6 @@ class FlavorList(task_manager.Task):
         return client.nova_client.flavors.list(**self.args)
 
 
-class FlavorGetExtraSpecs(task_manager.RequestTask):
-    result_key = 'extra_specs'
-
-    def main(self, client):
-        return client._compute_client.get(
-            "/flavors/{id}/os-extra_specs".format(**self.args))
-
-
-class FlavorSetExtraSpecs(task_manager.RequestTask):
-    result_key = 'extra_specs'
-
-    def main(self, client):
-        return client._compute_client.post(
-            "/flavors/{id}/os-extra_specs".format(**self.args),
-            json=self.args['json']
-            )
-
-
-class FlavorUnsetExtraSpecs(task_manager.RequestTask):
-
-    def main(self, client):
-        return client._compute_client.delete(
-            "/flavors/{id}/os-extra_specs/{key}".format(**self.args),
-            )
-
-
 class FlavorCreate(task_manager.Task):
     def main(self, client):
         return client.nova_client.flavors.create(**self.args)
@@ -267,18 +241,6 @@ class KeypairDelete(task_manager.Task):
         return client.nova_client.keypairs.delete(**self.args)
 
 
-class NovaListExtensions(task_manager.RequestTask):
-    result_key = 'extensions'
-
-    def main(self, client):
-        return client._compute_client.get('/extensions')
-
-
-class NovaUrlGet(task_manager.RequestTask):
-    def main(self, client):
-        return client._compute_client.get(**self.args)
-
-
 class NetworkList(task_manager.Task):
     def main(self, client):
         return client.neutron_client.list_networks(**self.args)
@@ -324,11 +286,6 @@ class RouterRemoveInterface(task_manager.Task):
         client.neutron_client.remove_interface_router(**self.args)
 
 
-class GlanceImageList(task_manager.Task):
-    def main(self, client):
-        return [image for image in self.args['image_gen']]
-
-
 class NovaImageList(task_manager.Task):
     def main(self, client):
         return client.nova_client.images.list()
@@ -339,36 +296,6 @@ class ImageSnapshotCreate(task_manager.Task):
         return client.nova_client.servers.create_image(**self.args)
 
 
-class ImageCreate(task_manager.Task):
-    def main(self, client):
-        return client.glance_client.images.create(**self.args)
-
-
-class ImageDelete(task_manager.Task):
-    def main(self, client):
-        return client.glance_client.images.delete(**self.args)
-
-
-class ImageTaskCreate(task_manager.Task):
-    def main(self, client):
-        return client.glance_client.tasks.create(**self.args)
-
-
-class ImageTaskGet(task_manager.Task):
-    def main(self, client):
-        return client.glance_client.tasks.get(**self.args)
-
-
-class ImageUpdate(task_manager.Task):
-    def main(self, client):
-        client.glance_client.images.update(**self.args)
-
-
-class ImageUpload(task_manager.Task):
-    def main(self, client):
-        client.glance_client.images.upload(**self.args)
-
-
 class VolumeCreate(task_manager.Task):
     def main(self, client):
         return client.cinder_client.volumes.create(**self.args)
@@ -539,66 +466,11 @@ class FloatingIPPoolList(task_manager.Task):
         return client.nova_client.floating_ip_pools.list()
 
 
-class ContainerGet(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.head_container(**self.args)
-
-
-class ContainerCreate(task_manager.Task):
-    def main(self, client):
-        client.swift_client.put_container(**self.args)
-
-
-class ContainerDelete(task_manager.Task):
-    def main(self, client):
-        client.swift_client.delete_container(**self.args)
-
-
-class ContainerUpdate(task_manager.Task):
-    def main(self, client):
-        client.swift_client.post_container(**self.args)
-
-
-class ContainerList(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.get_account(**self.args)[1]
-
-
-class ObjectCapabilities(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.get_capabilities(**self.args)
-
-
-class ObjectDelete(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.delete_object(**self.args)
-
-
 class ObjectCreate(task_manager.Task):
     def main(self, client):
         return client.swift_service.upload(**self.args)
 
 
-class ObjectUpdate(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.post_object(**self.args)
-
-
-class ObjectList(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.get_container(**self.args)[1]
-
-
-class ObjectMetadata(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.head_object(**self.args)
-
-
-class ObjectGet(task_manager.Task):
-    def main(self, client):
-        return client.swift_client.get_object(**self.args)
-
-
 class SubnetCreate(task_manager.Task):
     def main(self, client):
         return client.neutron_client.create_subnet(**self.args)
