@@ -14,6 +14,9 @@
 
 import sys
 
+import munch
+from requests import exceptions as _rex
+
 from shade import _log
 
 
@@ -21,11 +24,13 @@ class OpenStackCloudException(Exception):
 
     log_inner_exceptions = False
 
-    def __init__(self, message, extra_data=None):
+    def __init__(self, message, extra_data=None, **kwargs):
         args = [message]
         if extra_data:
-            args.append(extra_data)
-        super(OpenStackCloudException, self).__init__(*args)
+            if isinstance(extra_data, munch.Munch):
+                extra_data = extra_data.toDict()
+            args.append("Extra: {0}".format(str(extra_data)))
+        super(OpenStackCloudException, self).__init__(*args, **kwargs)
         self.extra_data = extra_data
         self.inner_exception = sys.exc_info()
         self.orig_message = message
@@ -38,8 +43,6 @@ class OpenStackCloudException(Exception):
 
     def __str__(self):
         message = Exception.__str__(self)
-        if self.extra_data is not None:
-            message = "%s (Extra: %s)" % (message, self.extra_data)
         if (self.inner_exception and self.inner_exception[1]
                 and not self.orig_message.endswith(
                     str(self.inner_exception[1]))):
@@ -63,9 +66,37 @@ class OpenStackCloudUnavailableFeature(OpenStackCloudException):
     pass
 
 
-class OpenStackCloudResourceNotFound(OpenStackCloudException):
-    pass
+class OpenStackCloudHTTPError(OpenStackCloudException, _rex.HTTPError):
+
+    def __init__(self, *args, **kwargs):
+        OpenStackCloudException.__init__(self, *args, **kwargs)
+        _rex.HTTPError.__init__(self, *args, **kwargs)
 
 
-class OpenStackCloudURINotFound(OpenStackCloudException):
+class OpenStackCloudURINotFound(OpenStackCloudHTTPError):
     pass
+
+# Backwards compat
+OpenStackCloudResourceNotFound = OpenStackCloudURINotFound
+
+
+# Logic shamelessly stolen from requests
+def raise_from_response(response):
+    msg = ''
+    if 400 <= response.status_code < 500:
+        msg = '({code}) Client Error: {reason} for url: {url}'.format(
+            code=response.status_code,
+            reason=response.reason,
+            url=response.url)
+    elif 500 <= response.status_code < 600:
+        msg = '({code}) Server Error: {reason} for url: {url}'.format(
+            code=response.status_code,
+            reason=response.reason,
+            url=response.url)
+
+    # Special case 404 since we raised a specific one for neutron exceptions
+    # before
+    if response.status_code == 404:
+        raise OpenStackCloudURINotFound(msg, response=response)
+    if msg:
+        raise OpenStackCloudHTTPError(msg, response=response)
