@@ -14,7 +14,6 @@
 
 import mock
 
-from shade import _utils
 from shade.tests.unit import base
 
 RAW_SERVER_DICT = {
@@ -208,7 +207,7 @@ class TestUtils(base.TestCase):
                 'cloud': '_test_cloud_',
                 'project': {
                     'domain_id': None,
-                    'domain_name': None,
+                    'domain_name': 'default',
                     'id': mock.ANY,
                     'name': 'admin'},
                 'region_name': u'RegionOne',
@@ -228,7 +227,7 @@ class TestUtils(base.TestCase):
             'rxtx_factor': 1600.0,
             'swap': 0,
             'vcpus': 8}
-        retval = self.cloud._normalize_flavor(raw_flavor).toDict()
+        retval = self.cloud._normalize_flavor(raw_flavor)
         self.assertEqual(expected, retval)
 
     def test_normalize_flavors_strict(self):
@@ -249,7 +248,7 @@ class TestUtils(base.TestCase):
                 'cloud': '_test_cloud_',
                 'project': {
                     'domain_id': None,
-                    'domain_name': None,
+                    'domain_name': 'default',
                     'id': mock.ANY,
                     'name': 'admin'},
                 'region_name': u'RegionOne',
@@ -261,7 +260,7 @@ class TestUtils(base.TestCase):
             'rxtx_factor': 1600.0,
             'swap': 0,
             'vcpus': 8}
-        retval = self.strict_cloud._normalize_flavor(raw_flavor).toDict()
+        retval = self.strict_cloud._normalize_flavor(raw_flavor)
         self.assertEqual(expected, retval)
 
     def test_normalize_nova_images(self):
@@ -297,7 +296,7 @@ class TestUtils(base.TestCase):
                 'cloud': '_test_cloud_',
                 'project': {
                     'domain_id': None,
-                    'domain_name': None,
+                    'domain_name': 'default',
                     'id': mock.ANY,
                     'name': 'admin'},
                 'region_name': u'RegionOne',
@@ -357,7 +356,7 @@ class TestUtils(base.TestCase):
             'updated_at': u'2015-02-15T23:04:34Z',
             'virtual_size': 0,
             'visibility': 'private'}
-        retval = self.cloud._normalize_image(raw_image).toDict()
+        retval = self.cloud._normalize_image(raw_image)
         self.assertEqual(expected, retval)
 
     def test_normalize_nova_images_strict(self):
@@ -376,7 +375,7 @@ class TestUtils(base.TestCase):
                 'cloud': '_test_cloud_',
                 'project': {
                     'domain_id': None,
-                    'domain_name': None,
+                    'domain_name': 'default',
                     'id': mock.ANY,
                     'name': 'admin'},
                 'region_name': u'RegionOne',
@@ -409,8 +408,9 @@ class TestUtils(base.TestCase):
             'status': u'active',
             'tags': [],
             'updated_at': u'2015-02-15T23:04:34Z',
-            'virtual_size': 0}
-        retval = self.strict_cloud._normalize_image(raw_image).toDict()
+            'virtual_size': 0,
+            'visibility': 'private'}
+        retval = self.strict_cloud._normalize_image(raw_image)
         self.assertEqual(sorted(expected.keys()), sorted(retval.keys()))
         self.assertEqual(expected, retval)
 
@@ -501,7 +501,7 @@ class TestUtils(base.TestCase):
             'visibility': u'private',
             u'vm_mode': u'hvm',
             u'xenapi_use_agent': u'False'}
-        retval = self.cloud._normalize_image(raw_image).toDict()
+        retval = self.cloud._normalize_image(raw_image)
         self.assertEqual(expected, retval)
 
     def test_normalize_glance_images_strict(self):
@@ -551,8 +551,9 @@ class TestUtils(base.TestCase):
             'status': u'active',
             'tags': [],
             'updated_at': u'2015-02-15T23:04:34Z',
-            'virtual_size': 0}
-        retval = self.strict_cloud._normalize_image(raw_image).toDict()
+            'virtual_size': 0,
+            'visibility': 'private'}
+        retval = self.strict_cloud._normalize_image(raw_image)
         self.assertEqual(sorted(expected.keys()), sorted(retval.keys()))
         self.assertEqual(expected, retval)
 
@@ -613,7 +614,7 @@ class TestUtils(base.TestCase):
             'user_id': u'e9b21dc437d149858faee0898fb08e92',
             'vm_state': u'active',
             'volumes': []}
-        retval = self.strict_cloud._normalize_server(raw_server).toDict()
+        retval = self.strict_cloud._normalize_server(raw_server)
         self.assertEqual(expected, retval)
 
     def test_normalize_servers_normal(self):
@@ -697,7 +698,7 @@ class TestUtils(base.TestCase):
             'user_id': u'e9b21dc437d149858faee0898fb08e92',
             'vm_state': u'active',
             'volumes': []}
-        retval = self.cloud._normalize_server(raw_server).toDict()
+        retval = self.cloud._normalize_server(raw_server)
         self.assertEqual(expected, retval)
 
     def test_normalize_secgroups_strict(self):
@@ -720,7 +721,7 @@ class TestUtils(base.TestCase):
                 region_name='RegionOne',
                 zone=None,
                 project=dict(
-                    domain_name=None,
+                    domain_name='default',
                     id=mock.ANY,
                     domain_id=None,
                     name='admin'),
@@ -735,7 +736,7 @@ class TestUtils(base.TestCase):
                          region_name='RegionOne',
                          zone=None,
                          project=dict(
-                             domain_name=None,
+                             domain_name='default',
                              id=mock.ANY,
                              domain_id=None,
                              name='admin'),
@@ -768,7 +769,7 @@ class TestUtils(base.TestCase):
                 region_name='RegionOne',
                 zone=None,
                 project=dict(
-                    domain_name=None,
+                    domain_name='default',
                     id=mock.ANY,
                     domain_id=None,
                     name='admin'),
@@ -785,7 +786,7 @@ class TestUtils(base.TestCase):
                          region_name='RegionOne',
                          zone=None,
                          project=dict(
-                             domain_name=None,
+                             domain_name='default',
                              id=mock.ANY,
                              domain_id=None,
                              name='admin'),
@@ -826,7 +827,7 @@ class TestUtils(base.TestCase):
                      region_name='RegionOne',
                      zone=None,
                      project=dict(
-                         domain_name=None,
+                         domain_name='default',
                          id=mock.ANY,
                          domain_id=None,
                          name='admin'),
@@ -837,36 +838,204 @@ class TestUtils(base.TestCase):
 
     def test_normalize_volumes_v1(self):
         vol = dict(
+            id='55db9e89-9cb4-4202-af88-d8c4a174998e',
             display_name='test',
             display_description='description',
             bootable=u'false',   # unicode type
             multiattach='true',  # str type
+            status='in-use',
+            created_at='2015-08-27T09:49:58-05:00',
         )
-        expected = dict(
-            name=vol['display_name'],
-            display_name=vol['display_name'],
-            description=vol['display_description'],
-            display_description=vol['display_description'],
-            bootable=False,
-            multiattach=True,
-        )
-        retval = _utils.normalize_volumes([vol])
-        self.assertEqual([expected], retval)
+        expected = {
+            'attachments': [],
+            'availability_zone': None,
+            'bootable': False,
+            'can_multiattach': True,
+            'consistencygroup_id': None,
+            'created_at': vol['created_at'],
+            'description': vol['display_description'],
+            'display_description': vol['display_description'],
+            'display_name': vol['display_name'],
+            'encrypted': False,
+            'host': None,
+            'id': '55db9e89-9cb4-4202-af88-d8c4a174998e',
+            'is_bootable': False,
+            'is_encrypted': False,
+            'location': {
+                'cloud': '_test_cloud_',
+                'project': {
+                    'domain_id': None,
+                    'domain_name': 'default',
+                    'id': mock.ANY,
+                    'name': 'admin'},
+                'region_name': u'RegionOne',
+                'zone': None},
+            'metadata': {},
+            'migration_status': None,
+            'multiattach': True,
+            'name': vol['display_name'],
+            'properties': {},
+            'replication_driver': None,
+            'replication_extended_status': None,
+            'replication_status': None,
+            'size': 0,
+            'snapshot_id': None,
+            'source_volume_id': None,
+            'status': vol['status'],
+            'updated_at': None,
+            'volume_type': None,
+        }
+        retval = self.cloud._normalize_volume(vol)
+        self.assertEqual(expected, retval)
 
     def test_normalize_volumes_v2(self):
         vol = dict(
+            id='55db9e89-9cb4-4202-af88-d8c4a174998e',
+            name='test',
+            description='description',
+            bootable=False,
+            multiattach=True,
+            status='in-use',
+            created_at='2015-08-27T09:49:58-05:00',
+            availability_zone='my-zone',
+        )
+        vol['os-vol-tenant-attr:tenant_id'] = 'my-project'
+        expected = {
+            'attachments': [],
+            'availability_zone': vol['availability_zone'],
+            'bootable': False,
+            'can_multiattach': True,
+            'consistencygroup_id': None,
+            'created_at': vol['created_at'],
+            'description': vol['description'],
+            'display_description': vol['description'],
+            'display_name': vol['name'],
+            'encrypted': False,
+            'host': None,
+            'id': '55db9e89-9cb4-4202-af88-d8c4a174998e',
+            'is_bootable': False,
+            'is_encrypted': False,
+            'location': {
+                'cloud': '_test_cloud_',
+                'project': {
+                    'domain_id': None,
+                    'domain_name': None,
+                    'id': vol['os-vol-tenant-attr:tenant_id'],
+                    'name': None},
+                'region_name': u'RegionOne',
+                'zone': vol['availability_zone']},
+            'metadata': {},
+            'migration_status': None,
+            'multiattach': True,
+            'name': vol['name'],
+            'os-vol-tenant-attr:tenant_id': vol[
+                'os-vol-tenant-attr:tenant_id'],
+            'properties': {
+                'os-vol-tenant-attr:tenant_id': vol[
+                    'os-vol-tenant-attr:tenant_id']},
+            'replication_driver': None,
+            'replication_extended_status': None,
+            'replication_status': None,
+            'size': 0,
+            'snapshot_id': None,
+            'source_volume_id': None,
+            'status': vol['status'],
+            'updated_at': None,
+            'volume_type': None,
+        }
+        retval = self.cloud._normalize_volume(vol)
+        self.assertEqual(expected, retval)
+
+    def test_normalize_volumes_v1_strict(self):
+        vol = dict(
+            id='55db9e89-9cb4-4202-af88-d8c4a174998e',
             display_name='test',
             display_description='description',
+            bootable=u'false',   # unicode type
+            multiattach='true',  # str type
+            status='in-use',
+            created_at='2015-08-27T09:49:58-05:00',
+        )
+        expected = {
+            'attachments': [],
+            'can_multiattach': True,
+            'consistencygroup_id': None,
+            'created_at': vol['created_at'],
+            'description': vol['display_description'],
+            'host': None,
+            'id': '55db9e89-9cb4-4202-af88-d8c4a174998e',
+            'is_bootable': False,
+            'is_encrypted': False,
+            'location': {
+                'cloud': '_test_cloud_',
+                'project': {
+                    'domain_id': None,
+                    'domain_name': 'default',
+                    'id': mock.ANY,
+                    'name': 'admin'},
+                'region_name': u'RegionOne',
+                'zone': None},
+            'metadata': {},
+            'migration_status': None,
+            'name': vol['display_name'],
+            'properties': {},
+            'replication_driver': None,
+            'replication_extended_status': None,
+            'replication_status': None,
+            'size': 0,
+            'snapshot_id': None,
+            'source_volume_id': None,
+            'status': vol['status'],
+            'updated_at': None,
+            'volume_type': None,
+        }
+        retval = self.strict_cloud._normalize_volume(vol)
+        self.assertEqual(expected, retval)
+
+    def test_normalize_volumes_v2_strict(self):
+        vol = dict(
+            id='55db9e89-9cb4-4202-af88-d8c4a174998e',
+            name='test',
+            description='description',
             bootable=False,
             multiattach=True,
+            status='in-use',
+            created_at='2015-08-27T09:49:58-05:00',
+            availability_zone='my-zone',
         )
-        expected = dict(
-            name=vol['display_name'],
-            display_name=vol['display_name'],
-            description=vol['display_description'],
-            display_description=vol['display_description'],
-            bootable=False,
-            multiattach=True,
-        )
-        retval = _utils.normalize_volumes([vol])
-        self.assertEqual([expected], retval)
+        vol['os-vol-tenant-attr:tenant_id'] = 'my-project'
+        expected = {
+            'attachments': [],
+            'can_multiattach': True,
+            'consistencygroup_id': None,
+            'created_at': vol['created_at'],
+            'description': vol['description'],
+            'host': None,
+            'id': '55db9e89-9cb4-4202-af88-d8c4a174998e',
+            'is_bootable': False,
+            'is_encrypted': False,
+            'location': {
+                'cloud': '_test_cloud_',
+                'project': {
+                    'domain_id': None,
+                    'domain_name': None,
+                    'id': vol['os-vol-tenant-attr:tenant_id'],
+                    'name': None},
+                'region_name': u'RegionOne',
+                'zone': vol['availability_zone']},
+            'metadata': {},
+            'migration_status': None,
+            'name': vol['name'],
+            'properties': {},
+            'replication_driver': None,
+            'replication_extended_status': None,
+            'replication_status': None,
+            'size': 0,
+            'snapshot_id': None,
+            'source_volume_id': None,
+            'status': vol['status'],
+            'updated_at': None,
+            'volume_type': None,
+        }
+        retval = self.strict_cloud._normalize_volume(vol)
+        self.assertEqual(expected, retval)
