@@ -15,6 +15,7 @@
 from keystoneauth1 import plugin as ksa_plugin
 
 import mock
+import munch
 import testtools
 
 from os_client_config import cloud_config
@@ -899,6 +900,64 @@ class TestShadeOperator(base.TestCase):
             state='active',
             configdrive='http://127.0.0.1/file.iso')
 
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_node_set_provision_state_wait_failure(self, mock_client):
+        class active_node_state:
+            provision_state = "active"
+
+        class deploy_failed_node_state:
+            provision_state = "deploy failed"
+
+        class clean_failed_node_state:
+            provision_state = "clean failed"
+
+        active_return_value = dict(
+            provision_state="active")
+        mock_client.node.get.return_value = active_node_state
+        mock_client.node.set_provision_state.return_value = None
+        node_id = 'node01'
+        return_value = self.op_cloud.node_set_provision_state(
+            node_id,
+            'active',
+            configdrive='http://127.0.0.1/file.iso',
+            wait=True)
+
+        self.assertEqual(active_return_value, return_value)
+        mock_client.node.set_provision_state.assert_called_with(
+            node_uuid='node01',
+            state='active',
+            configdrive='http://127.0.0.1/file.iso')
+        self.assertTrue(mock_client.node.get.called)
+        mock_client.mock_reset()
+        mock_client.node.get.return_value = deploy_failed_node_state
+        self.assertRaises(
+            shade.OpenStackCloudException,
+            self.op_cloud.node_set_provision_state,
+            node_id,
+            'active',
+            configdrive='http://127.0.0.1/file.iso',
+            wait=True,
+            timeout=300)
+        self.assertTrue(mock_client.node.get.called)
+        mock_client.node.set_provision_state.assert_called_with(
+            node_uuid='node01',
+            state='active',
+            configdrive='http://127.0.0.1/file.iso')
+        mock_client.mock_reset()
+        mock_client.node.get.return_value = clean_failed_node_state
+        self.assertRaises(
+            shade.OpenStackCloudException,
+            self.op_cloud.node_set_provision_state,
+            node_id,
+            'deleted',
+            wait=True,
+            timeout=300)
+        self.assertTrue(mock_client.node.get.called)
+        mock_client.node.set_provision_state.assert_called_with(
+            node_uuid='node01',
+            state='deleted',
+            configdrive=None)
+
     @mock.patch.object(shade.OperatorCloud, 'ironic_client')
     def test_node_set_provision_state_wait_provide(self, mock_client):
 
@@ -1019,27 +1078,25 @@ class TestShadeOperator(base.TestCase):
             node_id=uuid, patch=expected_patch
         )
 
-    @mock.patch.object(shade.OpenStackCloud, 'glance_client')
-    def test_get_image_name(self, glance_mock):
+    @mock.patch.object(shade.OpenStackCloud, '_image_client')
+    def test_get_image_name(self, mock_client):
 
-        class Image(object):
-            id = '22'
-            name = '22 name'
-            status = 'success'
-        fake_image = Image()
-        glance_mock.images.list.return_value = [fake_image]
+        fake_image = munch.Munch(
+            id='22',
+            name='22 name',
+            status='success')
+        mock_client.get.return_value = [fake_image]
         self.assertEqual('22 name', self.op_cloud.get_image_name('22'))
         self.assertEqual('22 name', self.op_cloud.get_image_name('22 name'))
 
-    @mock.patch.object(shade.OpenStackCloud, 'glance_client')
-    def test_get_image_id(self, glance_mock):
+    @mock.patch.object(shade.OpenStackCloud, '_image_client')
+    def test_get_image_id(self, mock_client):
 
-        class Image(object):
-            id = '22'
-            name = '22 name'
-            status = 'success'
-        fake_image = Image()
-        glance_mock.images.list.return_value = [fake_image]
+        fake_image = munch.Munch(
+            id='22',
+            name='22 name',
+            status='success')
+        mock_client.get.return_value = [fake_image]
         self.assertEqual('22', self.op_cloud.get_image_id('22'))
         self.assertEqual('22', self.op_cloud.get_image_id('22 name'))
 
